@@ -27,35 +27,38 @@
 
 #pragma once
 
-#include "calls-settings.h"
-
-#include <glib-object.h>
-#include <folks/folks.h>
-#include <libebook-contacts/libebook-contacts.h>
-
 #include "calls-best-match.h"
 
+#include <folks/folks.h>
+#include <glib-object.h>
+#include <libebook-contacts/libebook-contacts.h>
+
 G_BEGIN_DECLS
 
 G_DEFINE_AUTOPTR_CLEANUP_FUNC (GeeMap, g_object_unref)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC (GeeSet, g_object_unref)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC (GeeSortedSet, g_object_unref)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC (GeeCollection, g_object_unref)
+#if !EDS_CHECK_VERSION(3, 47, 1)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC (EPhoneNumber, e_phone_number_free)
+#endif
 
-typedef void (*IdleCallback) (gpointer        user_data,
+typedef void (*IdleCallback) (gpointer         user_data,
                               FolksIndividual *individual);
 
 #define CALLS_TYPE_CONTACTS_PROVIDER (calls_contacts_provider_get_type ())
 
-G_DECLARE_FINAL_TYPE (CallsContactsProvider, calls_contacts_provider, CALLS, CONTACTS_PROVIDER, GObject)
+G_DECLARE_FINAL_TYPE (CallsContactsProvider, calls_contacts_provider, CALLS, CONTACTS_PROVIDER, GObject);
 
-CallsContactsProvider  *calls_contacts_provider_new                  (CallsSettings         *settings);
-GeeCollection          *calls_contacts_provider_get_individuals      (CallsContactsProvider *self);
-CallsBestMatch         *calls_contacts_provider_lookup_phone_number  (CallsContactsProvider *self,
-                                                                      const gchar           *number);
-void                    calls_contacts_provider_consume_iter_on_idle (GeeIterator           *iter,
-                                                                      IdleCallback           callback,
-                                                                      gpointer               user_data);
+CallsContactsProvider *calls_contacts_provider_new                  (void);
+GeeCollection         *calls_contacts_provider_get_individuals      (CallsContactsProvider *self);
+CallsBestMatch        *calls_contacts_provider_lookup_id            (CallsContactsProvider *self,
+                                                                     const char            *id);
+void                   calls_contacts_provider_consume_iter_on_idle (GeeIterator *iter,
+                                                                     IdleCallback callback,
+                                                                     gpointer     user_data);
+gboolean               calls_contacts_provider_get_can_add_contacts (CallsContactsProvider *self);
+void                   calls_contacts_provider_add_new_contact      (CallsContactsProvider *self,
+                                                                     const char            *phone_number);
 
 G_END_DECLS
